CodeWord

Enum CodeWord 

pub enum CodeWord {
    W8,
    W16,
    W32,
    Other(u8),
}
The CodeWord is used to represent the size of the code word in bits.

The CodeWord enum defines the possible code words that can be used in galois fied. And the default value is W8, which is the most common code word size.

Variants



W8

A code word of 1 Byte.



W16

A code word of 2 Bytes.



W32

A code word of 4 Bytes.



Other(u8)

A code word of other size in bits.

Implementations

Source

impl CodeWord

pub fn from_u8(w: u8) -> Self

Makes a new CodeWord from the given size in bits.

pub fn to_u8(&self) -> u8

Returns the size of the code word in bits.