pub enum Error {
TooManyErasure(i32, i32),
InvalidArguments(String),
NotAligned(usize),
NotSupported(String),
Other(String),
}Expand description
The Error enum defines the possible errors that this crate can occur.
Variants
TooManyErasure(i32, i32)
TooManyErasure: The number of erasures is larger than the maximum allowed, and the lost data cannot be recovered.
InvalidArguments(String)
InvalidArguments: The the input is invalid.
NotAligned(usize)
NotAligned: The input is not a multiple of the machine long size.
NotSupported(String)
NotSupported: The input is not supported.
Other(String)
Other: Other errors that are not covered by the above.