CodingMethod

Enum CodingMethod 

pub enum CodingMethod {
    ReedSolVand,
    Cauchy,
    Liberation,
    Liber8tion,
    BlaumRoth,
}
The CodingMethod is used to represent the coding method used to encode and decode the data.

Each method has its own matrix generation algorithm. For more information, see the jerasure documentation

Variants



ReedSolVand

The Reed-Solomon Vandermonde coding method.

Requires

  • w must be in {8,16,32}
  • not supported for BitMatrix, Schedule, ScheduleCache


Cauchy

The Cauchy coding method.

Requires

  • packet_size must be set to a multiple of the machine long size


Liberation



Liber8tion



BlaumRoth