Crate jerasure_rs
jerasure_
rs
0.4.5
All Items
Crate Items
Modules
Enums
Crate
jerasure_
rs
Modules

erasure
The
erasure
module provides an interface for encoding and decoding data using erasure codes.
galois
The
galois
module provides functionality for performing operations in Galois fields.
Enums

Code
Word
The
CodeWord
is used to represent the size of the code word in bits.
Error
The
Error
enum defines the possible errors that this crate can occur.