ErasureCode

Struct ErasureCode 

pub struct ErasureCode { /* private fields */ }
The ErasureCode struct is used to encode and decode data using erasure codes.

It is a wrapper around the Jerasure library, which provides efficient implementations of various erasure coding techniques.

Implementations

Source

impl ErasureCode

pub fn k(&self) -> i32

Return the number of data devices.

pub fn m(&self) -> i32

Return the number of parity devices.

pub fn w(&self) -> CodeWord

Return the code word size.

pub fn tech(&self) -> Technique

Return the coding method.

pub fn encode<T: AsRef<[u8]>, U: AsMut<[u8]>>( &self, data: impl AsRef<[T]>, code: impl AsMut<[U]>, ) -> Result<(), Error>

Encode the data and generate coding parity.

Arguments
  • data - The data to encode, which must be a slice of k buffers of the same length.
  • code - The buffer to store the coding parity, which must be a slice of m buffers of the same length.
Requires
  • All the buffers must be aligned to the machine long size, and be the same length.
pub fn decode<T: AsMut<[u8]>>( &self, data: impl AsMut<[T]>, code: impl AsMut<[T]>, erased: &[i32], ) -> Result<(), Error>

Decode the data and recover the erased data.

Arguments
  • data - The data devices, which must be a slice of k buffers of the same length.
  • code - The coding devices, which must be a slice of m buffers of the same length.
  • erased - The indices of the erased data devices, which must be a slice of integers. The k data devices are indexed 0..k, and the m coding devices are indexed k..k+m.
Requires
  • All the buffers must be aligned to the machine long size, and be the same length.
  • The erased indices must be in the range of 0..k+m.
  • The number of erased indices must be less than or equal to m.
  • The erased indices must be unique.
Note

The erased devices may not be recovered even if the number of erased devices is less than or equal to m. This is because the coding matrix may not be full rank with large k and m. In this case, the function will return an error.